@@ -1,4 +1,4 @@
-"""Methods for referenceing Point objects: by.time, by.index, by.point"""
+"""Methods for referenceing Point objects: by.time, by.index, by.point\nUsage example:\n pytiers.get_point(1, by.Index())\n returns the point in the Tier object with the #1 index."""
 
 class Time(object):
     """When passed to \'by\', functions to state the Point object should be referenced by time. Essentially returns a string."""
