@@ -62,9 +62,7 @@ class Tier(object):
     def get_point(self, by_target, by):
         """Get Point of the Tier with chosen method. To change related parameters, use parameters.parameters."""
         
-        try:
-            by.by_method
-        except AttributeError:
+        if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
         
         if by.by_method=='by_time':
@@ -73,9 +71,12 @@ class Tier(object):
                     return point
 
         elif by.by_method=='by_index':
-            point = self.__points[by_target-1]
-            
-            return point
+            try:
+                point = self.__points[by_target-1]
+                
+                return point
+            except IndexError:
+                pass
 
         elif by.by_method=='by_point':
             for point in self.__points:
@@ -88,9 +89,7 @@ class Tier(object):
     def remove_point(self, by_target, by):
         """Remove Point of the Tier with chosen method. To change related parameters, use parameters.parameters."""
         
-        try:
-            by.by_method
-        except AttributeError:
+        if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
         
         point = self.get_point(by_target, by)
@@ -107,9 +106,7 @@ class Tier(object):
     def shift_point_to_time(self, target_time, by_target, by):
         """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use parameters.parameters."""
 
-        try:
-            by.by_method
-        except AttributeError:
+        if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
         
         point = self.get_point(by_target, by)
@@ -129,9 +126,7 @@ class Tier(object):
         """Batch raise or lower value of points of the Tier. To change related parameters, use parameters.parameters."""
         points = []
         
-        try:
-            by.by_method
-        except AttributeError:
+        if by.by_method not in _by.by_methods:
             raise Exception(f'Invalid by_method. Use help() to see valid methods.')
         
         if by.by_method=='by_point':
